Coverage for C:\src\imod-python\imod\flow\__init__.py: 95%

1"""

2 Create iMODFLOW model.

3

4 With this module full iMODFLOW models can be written to disk. Models in

5:mod:`imod.flow` are created in a similar way to those created in

6:mod:`imod.wq`. The ImodflowModel object by default writes iMODFLOW

7 projectfiles now instead of the older iMODFLOW runfiles.

8"""

9

10 from imod.flow.ani import HorizontalAnisotropy

11 from imod.flow.bas import Bottom, Boundary, StartingHead, Top

12 from imod.flow.cap import MetaSwap

13 from imod.flow.chd import ConstantHead

14 from imod.flow.conductivity import (

15 HorizontalHydraulicConductivity,

16 Transmissivity,

17 VerticalAnisotropy,

18 VerticalHydraulicConductivity,

19 VerticalResistance,

20)

21 from imod.flow.dis import TimeDiscretization

22 from imod.flow.drn import Drain

23 from imod.flow.evt import EvapoTranspiration

24 from imod.flow.ghb import GeneralHeadBoundary

25 from imod.flow.hfb import HorizontalFlowBarrier

26 from imod.flow.model import ImodflowModel

27 from imod.flow.oc import OutputControl

28 from imod.flow.rch import Recharge

29 from imod.flow.riv import River

30 from imod.flow.slv import PreconditionedConjugateGradientSolver

31 from imod.flow.sto import SpecificStorage, StorageCoefficient

32 from imod.flow.wel import Well

33

34

35 def write(path, model, name=None, runfile_parameters=None, output_packages=["shd"]):

36 """Removed function"""

37 raise NotImplementedError(

38 "This function has been removed. Use imod.flow.ImodflowModel instead."

39 )